@@ -1,33 +1,33 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-client-tls
-version: 0.2.3
-id: http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
-key: httpc_9zz2bALDbZz8lfJjVB5QvI
+version: 0.2.4
+id: http-client-tls-0.2.4-ad0e9a866e1feb2eac114d565c18f6c6
+key: httpc_LOkAmeH7akJ25hoLbSCu7G
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/snoyberg/http-client
 synopsis: http-client backend using the connection package and tls library
 description:
-    Intended for use by higher-level libraries, such as http-conduit.
+    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
 category: Network
 author: Michael Snoyman
 exposed: True
 exposed-modules:
     Network.HTTP.Client.TLS
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-tls-0.2.3
-hs-libraries: HShttp-client-tls-0.2.3-9zz2bALDbZz8lfJjVB5QvI
+import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-tls-0.2.4
+hs-libraries: HShttp-client-tls-0.2.4-LOkAmeH7akJ25hoLbSCu7G
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    connection-0.2.5-b1d9e33e03618093afb3c4e9d40c147e
+    connection-0.2.5-a80bc1c6fc57feb339146a3820d4e5af
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
-    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
+    http-client-0.4.28-3a5d04f7eb5922409c889a37b339ae0f
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
+    tls-1.3.8-96444b4e688bece54c4ea4192a68b9a3
 haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
 haddock-html: /usr/share/doc/haskell-http-client-tls/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
